@@ -19,6 +19,12 @@ def _single_get(item, key):
 
 
 def _recursive_getattr(item, keys):
+    # See if keys is as string, if so, we need to split on the dots.
+    try:
+        keys = keys.split('.')
+    except AttributeError:
+        pass
+
     if item is None:
         return None
     if len(keys) == 1:
@@ -48,18 +54,14 @@ class Col(object):
     def __init__(self, name, attr=None, attr_list=[]):
         self.name = name
         self._counter_val = Col._counter
-        self.attr = attr
         self.attr_list = attr_list
+        if attr:
+            self.attr_list = attr.split('.')
+        
         Col._counter += 1
 
-    @classmethod
-    def gettype(cls):
-        return cls.__name__
-
     def get_attr_list(self, attr):
-        if self.attr:
-            return self.attr.split('.')
-        elif self.attr_list:
+        if self.attr_list:
             return self.attr_list
         elif attr:
             return attr.split('.')
@@ -77,7 +79,7 @@ class Col(object):
         return '<td>%s</td>' % self.td_contents(i, self.get_attr_list(attr))
 
     def td_contents(self, i, attr_list):
-        """Given an item and an attr_list, return the contents of the
+        """Given an item and an attr, return the contents of the
         <td>.
 
         This method is a likely candidate to override when extending
@@ -106,18 +108,26 @@ class Col(object):
         return str(Markup.escape(str(content)))
 
 
-class BoolCol(Col):
-    """If the content is truthy, then output Yes. Otherwise output No.
+class OptCol(Col):
+    def __init__(self, name, choices={}, default_key=None, default_value='', coerce_fn=None, **kwargs):
+        Col.__init__(self, name, **kwargs)
+        self.choices = choices
+        self.default_value = choices.get(default_key, default_value)
+        self.coerce_fn = coerce_fn
 
-    TODO: generalise to a dict of options, plus a default.
-    TODO: account for internationalisation.
-
-    """
-    def td_format(self, content):
-        if content:
-            return 'Yes'
+    def coerce_content(self, content):
+        if self.coerce_fn:
+            return self.coerce_fn(content)
         else:
-            return 'No'
+            return content
+
+    def td_format(self, content):
+        return self.choices.get(self.coerce_content(content), self.default_value)
+
+
+class BoolCol(OptCol):
+    def __init__(self, name, **kwargs):
+        OptCol.__init__(self, name, choices={True: 'Yes', False: 'No'}, coerce_fn=bool, **kwargs)
 
 
 class DateCol(Col):
@@ -174,9 +184,7 @@ class LinkCol(Col):
     def url_kwargs(self, item):
         url_kwargs_out = {}
         for k, v in self._url_kwargs.items():
-            # TODO: replate getattr with _recursive_getattr, to
-            # maintain consistency.
-            url_kwargs_out[k] = getattr(item, v)
+            url_kwargs_out[k] = _recursive_getattr(item, v)
         return url_kwargs_out
 
     def get_attr_list(self, attr):
